@@ -504,7 +504,7 @@ class Cmnd(object):
         if icmRunArgs.cmndArgs:
             applicableCmndKwArgs.update({'argsList': icmRunArgs.cmndArgs})
 
-        # print(f"YYY == {applicableCmndKwArgs}")
+        # print(f"YYY 4444  == {applicableCmndKwArgs}")
         return applicableCmndKwArgs
 
     def invModel(self,
@@ -521,19 +521,20 @@ class Cmnd(object):
         G = cs.globalContext.get()
         icmRunArgs = G.icmRunArgsGet()
 
-        # print(f"cmndParamsMandatory={self.cmndParamsMandatory}")
-        # print(f"cmndParamsOptional={self.cmndParamsOptional}")
+        # print(f"NOTYET 4444 cmndParamsMandatory={self.cmndParamsMandatory}")
+        print(f"cmndParamsOptional={self.cmndParamsOptional}")
 
         if not pathlib.Path(baseDir).is_dir():
             print(f"BadUsage: Missing {baseDir}")
             return
 
-        #print(icmRunArgs)
+        # print(4444-100)
+        # print(icmRunArgs)
 
         applicableIcmParams = CmndParamDict()
 
         def absorbApplicableIcmParam(icmParam, each):
-            # print(f"4444 {each} {icmRunArgs.__dict__[each]}")
+            unrecognizedprint(f"4444 {each} {icmRunArgs.__dict__[each]}")
             icmParam.parValueSet(icmRunArgs.__dict__[each])
             applicableIcmParams.parDictAppend(eachIcmParam)
 
@@ -1007,6 +1008,7 @@ def commonIcmParamsParser(
 ** [[elisp:(org-cycle)][| *DocStr | ] Module Common Command Line Parameters.
     #+end_org """
 
+    print("NOTYET --- This Has been Obsoleted --- GGG")
     csParams = commonIcmParamsPrep()
 
     #argsparseBasedOnCsParams(parser, csParams)
@@ -1157,6 +1159,7 @@ def argsCommonProc(
      #dest='cmndArgs',   #
          metavar='CMND',
          nargs='*',
+         # nargs=argparse.REMAINDER,  NOTYET, Revisit this later
          action='store',
          help='Interactively Invokable Function Arguments'
          )
@@ -1168,6 +1171,7 @@ def argsCommonProc(
          default=[]
          )
 
+
      return
 
 ####+BEGIN: b:py3:cs:func/typing :funcName "G_argsProc" :funcType "extTyped" :deco "track"
@@ -1179,6 +1183,7 @@ def G_argsProc(
 ####+END:
         arguments,
         extraArgs,
+        ignoreUnknownParams=False,
 ):
      """ #+begin_org
 ** [[elisp:(org-cycle)][| *DocStr | ] ICM-ICM Argument Parser. extraArgs resides in the G_ module.
@@ -1215,9 +1220,60 @@ def G_argsProc(
              break
          index = index + 1
 
-     args = parser.parse_args(arguments)
+     args, unknown = parser.parse_known_intermixed_args(arguments)
 
-     return args, parser
+     # print(f"4444 -- Known arguments: {args}")
+     # print(f"4444 -- Unknown arguments: {unknown}")
+
+     if ignoreUnknownParams == False:
+         # This will result in a desired exception
+         if len(unknown):
+             args = parser.parse_args(arguments)
+     else:
+         # THE FOLLOWING WAS CODED WITH COPILOT CHAT-GPT
+         # We are going to ignore unknown parameters
+         # by removing them from arguments and running args = parser.parse_args(arguments)
+         # If we don't do this cmndArgs would be messed up
+         onlyKnownArgs = arguments.copy()
+         for each in unknown:
+             #  Look in unkown, decide if it should have a value and remove it and its value if any
+             # Find the first occurrence of this unknown token in the argument list
+             if each == "--":
+                 break
+             try:
+                 # locate index of token not already removed
+                 idx = None
+                 for i, tok in enumerate(onlyKnownArgs):
+                     if tok == each:
+                         idx = i
+                         break
+                 if idx is None:
+                     continue
+
+                 # remove the option itself
+                 onlyKnownArgs[idx] = None
+
+                 # If the token looks like an option that takes a separate value (e.g. '-x' or '--opt'),
+                 # and it is not of the form '--opt=val', then if the next token exists and
+                 # does not start with '-' treat it as the option's value and remove it too.
+                 tok = each
+                 if tok.startswith('-') and ('=' not in tok):
+                     nxt = idx + 1
+                     if nxt < len(onlyKnownArgs):
+                         nxt_tok = onlyKnownArgs[nxt]
+                         if nxt_tok is not None and (not str(nxt_tok).startswith('-')):
+                             onlyKnownArgs[nxt] = None
+             except Exception:
+                 # defensive: ignore any errors and continue
+                 continue
+
+         # Rebuild the argument list excluding removed tokens (None)
+         onlyKnownArgs = [t for t in onlyKnownArgs if t is not None]
+
+         # Parse using only the known args
+         args = parser.parse_args(onlyKnownArgs)
+
+     return args, unknown, parser
 
 ####+BEGIN: b:py3:cs:func/typing :funcName "argsparseBasedOnCsParams" :funcType "extTyped" :deco "track"
 """ #+begin_org
@@ -1312,6 +1368,8 @@ def G_main(
 ** [[elisp:(org-cycle)][| *DocStr | ] This is the main entry point for Python.Icm.Icm (InteractiveInvokationModules)
     #+end_org """
 
+    print(f"Is this b.cs.G_main being used at all -- Obsolete and Delete if NOT USED")
+
     #
     # The order is important here,
     # 1) Parse The Command Line -- 2) LOG_ usese the command line -- 3) G. setup
@@ -1360,6 +1418,7 @@ def G_mainWithClass(
         mainEntry=None,
         g_icmPreCmnds=None,
         g_icmPostCmnds=None,
+        ignoreUnknownParams=False,
 ):
     """ #+begin_org
 ** [[elisp:(org-cycle)][| *DocStr | ] This is the main entry point for Python.Icm.Icm (InteractiveInvokationModules)
@@ -1367,6 +1426,8 @@ def G_mainWithClass(
 Missing Feature. We want to use the logger inside of extraParamsHook.
     But, loggerSet needs runArgs.
 
+NOTYET: Problem, return value becomes exit code and that is inconsistent
+
     #+end_org """
 
     logControler = b_io.log.controller
@@ -1380,10 +1441,10 @@ Missing Feature. We want to use the logger inside of extraParamsHook.
     # With logArgv, we set the logger, before extraParamsHook is run
     # G_argsProc runs args parse without the extraArgs
     #
-    icmRunArgs, icmArgsParser = G_argsProc(logArgv, None)
+    icmRunArgs, unknownParams, icmArgsParser = G_argsProc(logArgv, None, ignoreUnknownParams=ignoreUnknownParams,)
     logControler.loggerSet(icmRunArgs)  # First loggerSet
 
-    icmRunArgs, icmArgsParser = G_argsProc(inArgv, extraArgs)   # runs extraArgs with logArgv
+    icmRunArgs, unknownParams, icmArgsParser = G_argsProc(inArgv, extraArgs, ignoreUnknownParams=ignoreUnknownParams,)   # runs extraArgs with logArgv
 
     logControler.loggerSet(icmRunArgs)  # second loggerSet, with extraArgs
 
@@ -1392,6 +1453,9 @@ Missing Feature. We want to use the logger inside of extraParamsHook.
     logger.info('Main Started: ' + b.ast.stackFrameInfoGet(1) )
 
     G = cs.globalContext.get()
+    # print(f"4444 -- {icmRunArgs}")
+    # print(f"4444.2 -- {unknownParams}")
+
     G.globalContextSet( icmRunArgs=icmRunArgs )
     G.icmArgsParser = icmArgsParser
     G.cmndMethodsDictSet(classedCmndsDict)
@@ -1405,7 +1469,7 @@ Missing Feature. We want to use the logger inside of extraParamsHook.
     if len( inArgv ) == 0:
         if G_examples:
             G_examples().cmnd(rtInv, outcome,)
-            return
+            return 0
 
     if icmRunArgs.invokes:
         thisCmndName=icmRunArgs.invokes[0]
