@@ -122,7 +122,10 @@ class CmndParam(object):
                   parDescription=None,
                   parDataType=None,
                   parDefault=None,
-                  parChoices=None,
+                  fileParInit=None,
+                  fileParName=None,
+                  # parChoices=None,
+                  parChoices=[],
                   parScope=None,
                   parMetavar=None,
                   parAction='store',                    # Same as argparse's action
@@ -138,6 +141,8 @@ class CmndParam(object):
          self.__parDescription = parDescription
          self.__parDataType = parDataType
          self.__parDefault = parDefault
+         self.__fileParInit = fileParInit
+         self.__fileParName = fileParName
          self.__parChoices = parChoices
          self.__parMetavar = parMetavar
          self.parActionSet(parAction)
@@ -169,10 +174,30 @@ description: {description}""".
          """        """
          return self.__parValue
 
+     def parValueSet(self, value):
+         """        """
+         self.__parValue = value
+
      def parFpValueSet(self, value):
          """        """
          self.__parFpValue = value
 
+     @property
+     def fileParInit(self) -> str | None:
+         return self.__fileParInit
+
+     @fileParInit.setter
+     def fileParInit(self, value: str | None,):
+         self.__fileParInit = value
+
+     @property
+     def fileParName(self) -> str | None:
+         return self.__fileParName
+
+     @fileParName.setter
+     def fileParName(self, value: str | None,):
+         self.__fileParName = value
+
      def parDescriptionGet(self):
          """        """
          return self.__parDescription
@@ -303,15 +328,19 @@ description: {description}""".
          if not parValue:
              parValue = "unSet"
 
+         fileParName = self.parNameGet()
+         if self.fileParName:
+             fileParName = self.fileParName
+
          b.fp.FileParamWriteTo(
              parRoot=absoluteParRoot,
-             parName=self.parNameGet(),
+             parName=fileParName,
              parValue=parValue,
          )
 
          varValueFullPath = os.path.join(
              absoluteParRoot,
-             self.parNameGet(),
+             fileParName,
              'description'
          )
 
@@ -322,7 +351,7 @@ description: {description}""".
 
          varValueBaseDir = os.path.join(
              absoluteParRoot,
-             self.parNameGet(),
+             fileParName,
              'enums'
          )
 
@@ -339,13 +368,13 @@ description: {description}""".
 #+end_org """
 class CmndParamDict(object):
 ####+END:
-     """ICM Parameters Dictionary -- Collection of CmndParam s can be placed in CmndParamDict
+     """CS Parameters Dictionary -- Collection of CmndParam s can be placed in CmndParamDict
 
-     From icmParamDict
+     From csParamDict
      """
 
      def __init__(self):
-         self.__icmParamDict = dict()
+         self.__csParamDict = dict()
 
      def parDictAdd(self,
                     parName=None,
@@ -353,7 +382,9 @@ class CmndParamDict(object):
                     parDataType=None,
                     parMetavar=None,
                     parDefault=None,
-                    parChoices=None,
+                    fileParInit=None,
+                    fileParName=None,
+                    parChoices=[],
                     parScope=None,
                     parAction='store',
                     parNargs=None,
@@ -366,6 +397,8 @@ class CmndParamDict(object):
                                parDataType=parDataType,
                                parMetavar=parMetavar,
                                parDefault=parDefault,
+                               fileParInit=fileParInit,
+                               fileParName=fileParName,
                                parChoices=parChoices,
                                parScope=parScope,
                                parAction=parAction,
@@ -377,18 +410,18 @@ class CmndParamDict(object):
          self.parDictAppend(thisParam)
          # print(f"rrr {thisParam}")
 
-     def parDictAppend(self, icmParam):
+     def parDictAppend(self, csParam):
          """        """
-         self.__icmParamDict.update({icmParam.parNameGet():icmParam})
+         self.__csParamDict.update({csParam.parNameGet():csParam})
 
 
      def parDictGet(self):
          """        """
-         return self.__icmParamDict
+         return self.__csParamDict
 
      def parNameFind(self, parName):
          """        """
-         found = self.__icmParamDict[parName]
+         found = self.__csParamDict[parName]
          return found
 
 
@@ -399,40 +432,36 @@ class CmndParamDict(object):
                                 ):
          """NOTYET -- Verify That Mandatory and Optional Params for this cmnd have been specified At Runtime."""
 
-         # if icmRunArgs.perfSap:
-         #     print(icmRunArgs.perfSap)
-
-         # if icmRunArgs.wsdlUrl:
-         #     print(icmRunArgs.wsdlUrl)
-
          return
 
-####+BEGIN: bx:cs:py3:func :funcName "commonIcmParamsPrep" :funcType "extTyped" :deco ""
+####+BEGIN: bx:cs:py3:func :funcName "commonCsParamsPrep" :funcType "extTyped" :deco ""
 """ #+begin_org
-*  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /commonIcmParamsPrep/  [[elisp:(org-cycle)][| ]]
+*  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /commonCsParamsPrep/  [[elisp:(org-cycle)][| ]]
 #+end_org """
-def commonIcmParamsPrep(
+def commonCsParamsPrep(
 ####+END:
 ) -> None:
     """ #+begin_org
 ** [[elisp:(org-cycle)][| *DocStr | ] Module Common Command Line Parameters.
     #+end_org """
 
-    icmParams = CmndParamDict()
+    print("NOTYET --- This Has been obsoleted??? ---- JJJJJJJJJJJJJJ")
 
-    icmParams.parDictAdd(
+    csParams = CmndParamDict()
+
+    csParams.parDictAdd(
         parAction='append',
-        parName='callTrackings',
+        parName='callTrackingsFF',
         parDescription="Set monitoring of calls and selected invokes.",
         parDataType=None,
         parDefault=[],
         parChoices=['invoke+', 'invoke-', 'monitor+', 'monitor-'],
         parScope=CmndParamScope.TargetParam,
         argparseShortOpt='-t',
-        argparseLongOpt='--callTrackings',
+        argparseLongOpt='--callTrackingsFF',  # NOTYET
         )
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='store',
         parName='runMode',
         parDescription="Run Mode as fullRun or dryRun",
@@ -444,7 +473,7 @@ def commonIcmParamsPrep(
         argparseLongOpt='--runMode',
         )
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='store',
         parName='verbosity',
         parDescription='Adds a Console Logger for the level specified in the range 1..50',
@@ -457,7 +486,7 @@ def commonIcmParamsPrep(
         argparseLongOpt='--verbosity',
         )
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='store',
         parName='logFile',
         parDescription='Specifies destination LogFile for this run',
@@ -470,7 +499,7 @@ def commonIcmParamsPrep(
         argparseLongOpt='--logFile',
         )
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='store',
         parName='sectionTitle',
         parDescription='For use as section title of examples',
@@ -483,7 +512,7 @@ def commonIcmParamsPrep(
         argparseLongOpt='--sectionTitle',
         )
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='store',
         parName='logFileLevel',
         parDescription='Specifies destination LogFile for this run',
@@ -496,7 +525,7 @@ def commonIcmParamsPrep(
         argparseLongOpt='--logFileLevel',
         )
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='store_true',
         parName='docstring',
         parDescription='Docstring',
@@ -506,10 +535,23 @@ def commonIcmParamsPrep(
         parChoices=[],
         parScope=CmndParamScope.TargetParam,
         #argparseShortOpt='-v',
-        argparseLongOpt='--logFileLevel',
+        argparseLongOpt='--docString',
         )
 
-    # icmParams.parDictAdd(
+    csParams.parDictAdd(
+        parAction='store_true',
+        parName='force',
+        parDescription='Over writes default behaviour and forces actions',
+        parDataType=None,
+        parDefault=None,
+        parMetavar='ARG',
+        parChoices=[],
+        parScope=CmndParamScope.TargetParam,
+        argparseShortOpt='-f',
+        argparseLongOpt='--force',
+        )
+
+    # csParams.parDictAdd(
     #
     #     parAction='store',
     #     parName='cmndArgs',
@@ -524,7 +566,7 @@ def commonIcmParamsPrep(
     #     )
 
 
-    icmParams.parDictAdd(
+    csParams.parDictAdd(
         parAction='append',
         parName='loadfiles',
         parDescription='Load Files',
@@ -538,13 +580,15 @@ def commonIcmParamsPrep(
         )
 
 
-    return icmParams
+    return csParams
 
-####+BEGIN: bx:cs:py3:func :funcName "icmParamsToFileParamsUpdate" :funcType "extTyped" :deco ""
+commonIcmParamsPrep = commonCsParamsPrep
+
+####+BEGIN: bx:cs:py3:func :funcName "csParamsToFileParamsUpdate" :funcType "extTyped" :deco ""
 """ #+begin_org
-*  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /icmParamsToFileParamsUpdate/  [[elisp:(org-cycle)][| ]]
+*  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /csParamsToFileParamsUpdate/  [[elisp:(org-cycle)][| ]]
 #+end_org """
-def icmParamsToFileParamsUpdate(
+def csParamsToFileParamsUpdate(
 ####+END:
         parRoot,
         icmParams,
@@ -565,6 +609,8 @@ def icmParamsToFileParamsUpdate(
 
     return
 
+icmParamsToFileParamsUpdate = csParamsToFileParamsUpdate
+
 ####+BEGIN: bx:cs:py3:func :funcName "cmndParamsMandatoryAssert" :funcType "extTyped" :deco ""
 """ #+begin_org
 *  _[[elisp:(blee:menu-sel:outline:popupMenu)][±]]_ _[[elisp:(blee:menu-sel:navigation:popupMenu)][Ξ]]_ [[elisp:(outline-show-branches+toggle)][|=]] [[elisp:(bx:orgm:indirectBufOther)][|>]] *[[elisp:(blee:ppmm:org-mode-toggle)][|N]]*  F-extTyped [[elisp:(outline-show-subtree+toggle)][||]] /cmndParamsMandatoryAssert/  [[elisp:(org-cycle)][| ]]
